@@ -47,7 +47,7 @@ class Pound(object):
         self.options.setdefault('alive', 30)
         self.options.setdefault('timeout', 60)
         self.options.setdefault('xHTTP', 0)
-        self.options.setdefault('template', sibpath("pound.cfg")
+        self.options.setdefault('template', sibpath("pound.cfg"))
         self.options["__hashes_template"] = sha1(open(self.options["template"]).read()).hexdigest()
 
     def install(self):
